import{V as l,m as g}from"./VCheckboxBtn-DpMGI-si.js";import{g as A,p as F,j as R,d0 as B,J as U,d5 as j,n as w,d6 as D,d1 as r,o as u,ae as d,ap as J,ai as M,d2 as N}from"./index-D-FY8Yx2.js";const $=F({...N(),...M(g(),["inline"])},"VCheckbox"),E=A()({name:"VCheckbox",inheritAttrs:!1,props:$(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,c){let{attrs:n,slots:o}=c;const s=R(e,"modelValue"),{isFocused:i,focus:m,blur:V}=B(e),t=U(),f=j();return w(()=>{const[p,b]=D(n),k=r.filterProps(e),v=l.filterProps(e);return u(r,d({ref:t,class:["v-checkbox",e.class]},p,k,{modelValue:s.value,"onUpdate:modelValue":a=>s.value=a,id:e.id||`checkbox-${f}`,focused:i.value,style:e.style}),{...o,default:a=>{let{id:x,messagesId:h,isDisabled:P,isReadonly:C,isValid:y}=a;return u(l,d(v,{id:x.value,"aria-describedby":h.value,disabled:P.value,readonly:C.value},b,{error:y.value===!1,modelValue:s.value,"onUpdate:modelValue":I=>s.value=I,onFocus:m,onBlur:V}),o)}})}),J({},t)}});export{E as V};
