import{ay as r,az as l,aA as n,ah as d,aB as o,q as s,E as e}from"./index-D-FY8Yx2.js";const y=r({__name:"NowPlayingBadge",props:{showBadge:{type:Boolean,default:!0},showIcon:{type:Boolean,default:!0},badgeStyle:{default:""},iconStyle:{default:""}},setup(a){return(i,t)=>(n(),l(d,null,[a.showBadge?(n(),l("span",{key:0,style:s(a.badgeStyle),class:"now-playing-badge","aria-label":"Now playing"}," Now playing ",4)):o("",!0),a.showIcon?(n(),l("div",{key:1,style:s(a.iconStyle),class:"now-playing-icon"},[...t[0]||(t[0]=[e("div",{class:"bar"},null,-1),e("div",{class:"bar"},null,-1),e("div",{class:"bar"},null,-1),e("div",{class:"bar"},null,-1)])],4)):o("",!0)],64))}});export{y as _};
