.v-combobox--chips.v-input--density-compact .v-field--variant-solo .v-label.v-field-label--floating,.v-combobox--chips.v-input--density-compact .v-field--variant-solo-inverted .v-label.v-field-label--floating,.v-combobox--chips.v-input--density-compact .v-field--variant-filled .v-label.v-field-label--floating,.v-combobox--chips.v-input--density-compact .v-field--variant-solo-filled .v-label.v-field-label--floating{top:0}.v-combobox .v-field .v-text-field__prefix,.v-combobox .v-field .v-text-field__suffix,.v-combobox .v-field .v-field__input,.v-combobox .v-field .v-field__input>input,.v-combobox .v-field.v-field{cursor:text}.v-combobox .v-field .v-field__input>input{flex:1 1}.v-combobox .v-field input{min-width:64px}.v-combobox .v-field:not(.v-field--focused) input{min-width:0}.v-combobox .v-field--dirty .v-combobox__selection{margin-inline-end:2px}.v-combobox .v-combobox__selection-text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.v-combobox__content{overflow:hidden}.v-combobox__content{box-shadow:0 2px 4px -1px var(--v-shadow-key-umbra-opacity, rgba(0, 0, 0, .2)),0 4px 5px 0 var(--v-shadow-key-penumbra-opacity, rgba(0, 0, 0, .14)),0 1px 10px 0 var(--v-shadow-key-ambient-opacity, rgba(0, 0, 0, .12))}.v-menu>.v-overlay__content.v-combobox__content{border-radius:4px}.v-combobox__mask{background:rgb(var(--v-theme-surface-light))}.v-combobox__selection{display:inline-flex;align-items:center;height:1.5rem;letter-spacing:inherit;line-height:inherit;max-width:calc(100% - 4px)}.v-combobox__selection:first-child{margin-inline-start:0}.v-combobox--selecting-index .v-combobox__selection{opacity:var(--v-medium-emphasis-opacity)}.v-combobox--selecting-index .v-combobox__selection--selected{opacity:1}.v-combobox--selecting-index .v-field__input>input{caret-color:transparent}.v-combobox--single:not(.v-combobox--selection-slot).v-text-field input{flex:1 1;position:absolute;left:0;right:0;width:100%;padding-inline:inherit}.v-combobox--single:not(.v-combobox--selection-slot) .v-field--active input{transition:none}.v-combobox--single:not(.v-combobox--selection-slot) .v-field--dirty:not(.v-field--focused) input{opacity:0}.v-combobox--single:not(.v-combobox--selection-slot) .v-field--focused .v-combobox__selection{opacity:0}.v-combobox__menu-icon{margin-inline-start:4px;transition:.2s cubic-bezier(.4,0,.2,1)}.v-combobox--active-menu .v-combobox__menu-icon{transform:rotate(180deg)}.config-field[data-v-4469350e]{flex:1;min-width:0}.config-divider[data-v-4469350e]{padding:8px 0}.divider-label[data-v-4469350e]{display:block;margin-top:12px;font-weight:600;font-size:.875rem}.config-alert[data-v-4469350e],.action-btn[data-v-4469350e]{margin:8px 0}.dsp-config[data-v-4469350e]{display:flex;align-items:center;gap:16px;padding:8px 0}.dsp-status[data-v-4469350e]{font-size:.875rem;color:rgba(var(--v-theme-on-surface),.7)}.config-slider[data-v-4469350e]{padding-top:8px}.config-section[data-v-4926e606]{margin-bottom:16px}.config-entry[data-v-4926e606]{display:flex;align-items:flex-start;gap:8px;margin-bottom:8px}.config-entry[data-v-4926e606]:last-child{margin-bottom:0}.config-entry:has(.v-checkbox)+.config-entry[data-v-4926e606]:has(.v-text-field),.config-entry:has(.v-checkbox)+.config-entry[data-v-4926e606]:has(.v-select),.config-entry:has(.v-checkbox)+.config-entry[data-v-4926e606]:has(.v-slider),.config-entry:has(.v-checkbox)+.config-entry[data-v-4926e606]:has(.v-combobox){margin-top:16px}.help-btn[data-v-4926e606]{flex-shrink:0;margin-top:8px;opacity:.6;transition:opacity .2s ease}.help-btn[data-v-4926e606]:hover{opacity:1}.config-panels[data-v-4926e606]{margin-top:16px}.config-panel[data-v-4926e606]{margin-bottom:8px;border:1px solid rgba(var(--v-theme-on-surface),.12);border-radius:8px!important;overflow:hidden}.config-panel[data-v-4926e606]:before{display:none}.config-panel-title[data-v-4926e606]{min-height:52px;padding:14px 20px;background:rgba(var(--v-theme-primary),.08)}.config-panel-title .v-icon[data-v-4926e606]{color:rgb(var(--v-theme-primary))}.panel-title-text[data-v-4926e606]{font-size:1.1rem;font-weight:600;color:rgb(var(--v-theme-primary))}.config-panel[data-v-4926e606] .v-expansion-panel-text__wrapper{padding:0}.config-panel-content[data-v-4926e606]{padding:16px 20px 20px;border-top:1px solid rgba(var(--v-theme-on-surface),.08)}.config-actions[data-v-4926e606]{display:flex;flex-direction:column;gap:12px;margin-top:24px;padding-top:16px}
