import{I as c}from"./ItemsListing-p3UDrkaz.js";import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_style_index_0_lang-CPJnCCao.js";import{ay as h,J as y,L as I,az as w,aA as s,o as V,aI as m,aB as l,E as g,aP as n,c8 as k}from"./index-D-FY8Yx2.js";import"./Container-C7DumkgJ.js";import"./index-kQIztB-E.js";import"./Toolbar-CxAnowGj.js";import"./VToolbar-BGzu4h11.js";import"./Button-B57MCuAc.js";import"./ListItem-CX5q61ih.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-B1j6uBGW.js";import"./MediaItemThumb-CzEoSAF3.js";import"./VCheckbox-W6o6QHjE.js";import"./VCheckboxBtn-DpMGI-si.js";import"./VSelectionControl-CyrHFsUF.js";import"./PanelviewItemCompact-BY3CNldl.js";import"./userPreferences-7uBq50Yx.js";import"./VInfiniteScroll-CRxNfWga.js";import"./VVirtualScroll-cGuYysLa.js";import"./marquee_text_sync-OdthARHF.js";const q=h({__name:"RadioDetails",props:{itemId:{},provider:{}},setup(a){const t=a,e=y(),p=async function(){e.value=await n.getRadio(t.itemId,t.provider)};I(()=>t.itemId,o=>{o&&p()},{immediate:!0});const d=async function(o){const i=[];if(t.provider=="library"){const r=await n.getRadioVersions(t.itemId,t.provider);i.push(...r)}for(const r of k(e.value)){const u=await n.getRadioVersions(r.item_id,r.provider_instance);i.push(...u)}return i};return(o,i)=>(s(),w("section",null,[V(f,{item:e.value},null,8,["item"]),e.value?(s(),m(c,{key:0,itemtype:"radioversions","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library":!1,"show-radio-number":!1,"show-duration":!1,"load-items":d,"sort-keys":["provider","sort_name"],title:o.$t("other_versions"),"hide-on-empty":!0,checksum:a.provider+a.itemId},null,8,["parent-item","title","checksum"])):l("",!0),i[0]||(i[0]=g("br",null,null,-1)),e.value?(s(),m(v,{key:1,"item-details":e.value},null,8,["item-details"])):l("",!0)]))}});export{q as default};
