import{ay as R,a3 as f,aI as s,aA as t,aZ as p,aD as o,bX as k,aG as n,b0 as h,az as c,r as C,o as r,E as v,aB as m,M as g,aW as V,aN as b,b6 as B,bT as $,ah as x,aH as A,bY as M,bi as I,bZ as T,aQ as u,_ as N}from"./index-D-FY8Yx2.js";import{P}from"./PanelviewItemCompact-BY3CNldl.js";import{V as z}from"./VToolbar-BGzu4h11.js";const E=R({__name:"Carousel",setup(e){return f(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(d,l)=>{const w=p("swiper");return t(),s(w,{"slides-per-view":o(k)(d.$vuetify.display.width)+.5,"free-mode":!0,navigation:!1,mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:n(()=>[h(d.$slots,"default")]),_:3},8,["slides-per-view"])}}}),O={class:"mr-3"},W={key:0},D={class:"carousel-wrapper"},L=R({__name:"WidgetRow",props:{widgetRow:{},editMode:{type:Boolean},showProviderOnCover:{type:Boolean}},emits:["update:settings"],setup(e,{emit:d}){const l=d;return(w,a)=>{const y=p("swiper-slide");return t(),c("div",{class:C(`widget-row ${e.widgetRow.settings&&!e.widgetRow.settings.enabled?"disabled":""}`)},[r(z,{class:"header",color:"transparent"},{title:n(()=>[v("span",O,b(e.widgetRow.title),1),e.widgetRow.subtitle&&o(B)("bp6")?(t(),s($,{key:0,inline:"",outlined:"",text:e.widgetRow.subtitle,density:"compact",size:"small"},null,8,["text"])):m("",!0)]),append:n(()=>[e.editMode&&e.widgetRow.settings?(t(),c("div",W,[e.widgetRow.settings.position!==0?(t(),s(g,{key:0,icon:"mdi-chevron-up",class:"enabled",onClick:a[0]||(a[0]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position-1}))})):m("",!0),r(g,{icon:"mdi-chevron-down",onClick:a[1]||(a[1]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position+1}))}),r(g,{icon:e.widgetRow.settings.enabled?"mdi-checkbox-marked":"mdi-checkbox-blank-outline",onClick:a[2]||(a[2]=i=>l("update:settings",{...e.widgetRow.settings,enabled:!e.widgetRow.settings.enabled}))},null,8,["icon"])])):e.widgetRow.provider?(t(),s(V,{key:1,domain:e.widgetRow.provider,size:24},null,8,["domain"])):m("",!0)]),_:1}),v("div",D,[e.widgetRow.items.length>0?(t(),s(E,{key:0},{default:n(()=>[(t(!0),c(x,null,A(e.widgetRow.items,i=>(t(),s(y,{key:i.uri},{default:n(()=>[r(P,{item:i,"show-provider-on-cover":e.showProviderOnCover,"permanent-overlay":![o(u).ALBUM,o(u).TRACK,o(u).RADIO].includes(i.media_type),"is-available":o(T)(i),disabled:e.editMode},null,8,["item","show-provider-on-cover","permanent-overlay","is-available","disabled"])]),_:2},1024))),128))]),_:1})):(t(),s(M,{key:1},{default:n(()=>[I(b(w.$t("no_content")),1)]),_:1}))])],2)}}}),G=N(L,[["__scopeId","data-v-a88771f6"]]);export{G as W};
